@@ -23,7 +23,7 @@
 
 #include <QDir>
 #include <QFileDialog>
-#include <QDesktopWidget>
+#include <QScreen>
 #include <QHash>
 #include <QHashIterator>
 #include <QRegExp>
@@ -37,37 +37,18 @@ MainWindow::MainWindow(QWidget* parent) : QMainWindow(parent),
     _ui->setupUi(this);
     _trayed = false;
 
-#ifdef SG_GLOBAL_SHORTCUTS
-    // signal mapper
-    _globalShortcutSignals = new QSignalMapper(this);
-
-    // global shortcuts
-    _fullScreen = new QxtGlobalShortcut(this);
-    _activeWindow = new QxtGlobalShortcut(this);
-    _areaSelection = new QxtGlobalShortcut(this);
-    _globalShortcuts << _fullScreen << _activeWindow << _areaSelection;
-
-    for (int i = 0; i < _globalShortcuts.count(); ++i )
-    {
-        connect(_globalShortcuts[i], SIGNAL(activated()), _globalShortcutSignals, SLOT(map()) );
-        _globalShortcutSignals->setMapping(_globalShortcuts[i], i);
-    }
-
-    connect(_globalShortcutSignals, SIGNAL(mapped(int)), this, SLOT(globalShortcutActivate(int)));
-#endif
-
     _trayIcon = nullptr;
     _hideWnd = nullptr;
     _trayMenu = nullptr;
 
     // create actions menu
-    actNew = new QAction(QIcon::fromTheme("document-new"), tr("New"), this);
-    actSave = new QAction(QIcon::fromTheme("document-save"), tr("Save"), this);
-    actCopy = new QAction(QIcon::fromTheme("edit-copy"), tr("Copy"), this);
-    actOptions = new QAction(QIcon::fromTheme("configure"), tr("Options"), this);
-    actHelp = new QAction(QIcon::fromTheme("system-help"), tr("Help"), this);
-    actAbout = new QAction(QIcon::fromTheme("system-about"), tr("About"), this);
-    actQuit = new QAction(QIcon::fromTheme("application-exit"), tr("Quit"), this);
+    actNew = new QAction(QIcon::fromTheme(QStringLiteral("document-new")), tr("New"), this);
+    actSave = new QAction(QIcon::fromTheme(QStringLiteral("document-save")), tr("Save"), this);
+    actCopy = new QAction(QIcon::fromTheme(QStringLiteral("edit-copy")), tr("Copy"), this);
+    actOptions = new QAction(QIcon::fromTheme(QStringLiteral("configure")), tr("Options"), this);
+    actHelp = new QAction(QIcon::fromTheme(QStringLiteral("system-help")), tr("Help"), this);
+    actAbout = new QAction(QIcon::fromTheme(QStringLiteral("system-about")), tr("About"), this);
+    actQuit = new QAction(QIcon::fromTheme(QStringLiteral("application-exit")), tr("Quit"), this);
 
     // connect actions to slots
     Core *c = Core::instance();
@@ -91,7 +72,7 @@ MainWindow::MainWindow(QWidget* parent) : QMainWindow(parent),
     QToolButton *help = new QToolButton(this);
     help->setText(tr("Help"));
     help->setPopupMode(QToolButton::InstantPopup);
-    help->setIcon(QIcon::fromTheme("system-help"));
+    help->setIcon(QIcon::fromTheme(QStringLiteral("system-help")));
     help->setMenu(menuInfo);
 
     _ui->toolBar->addWidget(help);
@@ -110,13 +91,14 @@ MainWindow::MainWindow(QWidget* parent) : QMainWindow(parent),
     connect(_ui->checkNoDecoration, &QCheckBox::toggled, this, &MainWindow::checkNoDecoration);
     connect(_ui->checkZommMouseArea, &QCheckBox::toggled, this, &MainWindow::checkZommMouseArea);
 
-    appIcon = QIcon::fromTheme ("screengrab");
+    appIcon = QIcon::fromTheme (QStringLiteral("screengrab"));
     if (appIcon.isNull())
-        appIcon = QIcon(":/res/img/logo.png");
+        appIcon = QIcon(QStringLiteral(":/res/img/logo.png"));
 
     setWindowIcon(appIcon);
 
-    QRect geometry = QApplication::desktop()->availableGeometry(QApplication::desktop()->screenNumber());
+    auto screens = QGuiApplication::screens();
+    const QRect geometry = screens.isEmpty() ? QRect() : screens.at(0)->availableGeometry();
     move(geometry.width() / 2 - width() / 2, geometry.height() / 2 - height() / 2);
 
     _ui->scrLabel->installEventFilter(this);
@@ -209,7 +191,7 @@ void MainWindow::updateModulesActions(const QList<QAction *> &list)
     }
 }
 
-void MainWindow::updateModulesenus(const QList<QMenu *> &list)
+void MainWindow::updateModulesMenus(const QList<QMenu *> &list)
 {
     if (list.count() > 0)
     {
@@ -290,17 +272,17 @@ void MainWindow::showHelp()
 {
     QString localeHelpFile;
 
-    localeHelpFile = QString(SG_DOCDIR) + "%1html%1" + Config::getSysLang()+"%1index.html";
+    localeHelpFile = QStringLiteral(SG_DOCDIR) + QStringLiteral("%1html%1") + Config::getSysLang()+QStringLiteral("%1index.html");
     localeHelpFile = localeHelpFile.arg(QString(QDir::separator()));
 
     if (!QFile::exists(localeHelpFile))
     {
-        localeHelpFile = QString(SG_DOCDIR) + "%1html%1" + Config::getSysLang().section("_", 0, 0)  + "%1index.html";
+        localeHelpFile = QStringLiteral(SG_DOCDIR) + QStringLiteral("%1html%1") + Config::getSysLang().section(QStringLiteral("_"), 0, 0)  + QStringLiteral("%1index.html");
         localeHelpFile = localeHelpFile.arg(QString(QDir::separator()));
 
         if (!QFile::exists(localeHelpFile))
         {
-            localeHelpFile = QString(SG_DOCDIR) + "%1html%1en%1index.html";
+            localeHelpFile = QStringLiteral(SG_DOCDIR) + QStringLiteral("%1html%1en%1index.html");
             localeHelpFile = localeHelpFile.arg(QString(QDir::separator()));
         }
     }
@@ -313,9 +295,6 @@ void MainWindow::showHelp()
 void MainWindow::showOptions()
 {
     ConfigDialog *options = new ConfigDialog(this);
-#ifdef SG_GLOBAL_SHORTCUTS
-    globalShortcutBlock(true);
-#endif
 
     if (isMinimized())
     {
@@ -333,9 +312,6 @@ void MainWindow::showOptions()
             updateUI();
     }
 
-#ifdef SG_GLOBAL_SHORTCUTS
-    globalShortcutBlock(false);
-#endif
     delete options;
 }
 
@@ -362,10 +338,10 @@ void MainWindow::displatScreenToolTip()
     QSize pSize = Core::instance()->getPixmap()->size();
     quint16 w = pSize.width();
     quint16 h = pSize.height();
-    QString toolTip = tr("Screenshot ") + QString::number(w) + "x" + QString::number(h);
+    QString toolTip = tr("Screenshot ") + QString::number(w) + QStringLiteral("x") + QString::number(h);
     if (_conf->getEnableExtView())
     {
-        toolTip += "\n\n";
+        toolTip += QLatin1String("\n\n");
         toolTip += tr("Double click to open screenshot in external default image viewer");
     }
 
@@ -580,7 +556,7 @@ void MainWindow::saveScreen()
     QHash<QString, QString>::const_iterator iter = formatsAvalible.constBegin();
     while (iter != formatsAvalible.constEnd())
     {
-        QString str = iter.value() + " (*." + iter.key() + ")";
+        QString str = iter.value() + QStringLiteral(" (*.") + iter.key() + QStringLiteral(")");
         if (iter.key() == format)
             filterSelected = str;
         fileFilters << str;
@@ -588,9 +564,9 @@ void MainWindow::saveScreen()
     }
 
     QString fileName;
-    fileName = QFileDialog::getSaveFileName(this, tr("Save As..."),  filePath, fileFilters.join(";;"), &filterSelected);
+    fileName = QFileDialog::getSaveFileName(this, tr("Save As..."),  filePath, fileFilters.join(QStringLiteral(";;")), &filterSelected);
 
-    QRegExp rx(R"(\(\*\.[a-z]{3,4}\))");
+    QRegExp rx(QStringLiteral(R"(\(\*\.[a-z]{3,4}\))"));
     quint8 tmp = filterSelected.size() - rx.indexIn(filterSelected);
 
     filterSelected.chop(tmp + 1);
@@ -617,28 +593,4 @@ void MainWindow::updateShortcuts()
     actOptions->setShortcut(_conf->shortcuts()->getShortcut(Config::shortcutOptions));
     actHelp->setShortcut(_conf->shortcuts()->getShortcut(Config::shortcutHelp));
     actQuit->setShortcut(_conf->shortcuts()->getShortcut(Config::shortcutClose));
-
-#ifdef SG_GLOBAL_SHORTCUTS
-    for (int i = 0; i < _globalShortcuts.count(); ++i)
-        _globalShortcuts[i]->setShortcut(QKeySequence(_core->conf->shortcuts()->getShortcut(i)));
-#endif
 }
-
-#ifdef SG_GLOBAL_SHORTCUTS
-void MainWindow::globalShortcutBlock(bool state)
-{
-    for (int i = 0; i < _globalShortcuts.count(); ++i)
-        _globalShortcuts[i]->setDisabled(state);
-}
-
-
-void MainWindow::globalShortcutActivate(int type)
-{
-    _ui->cbxTypeScr->setCurrentIndex(type);
-    typeScreenShotChange(type);
-
-    if (!_trayed)
-        hide();
-    QTimer::singleShot(200, _core, SLOT(screenShot()));
-}
-#endif
