@@ -21,12 +21,12 @@
     <message>
         <location filename="../src/core/ui/about.cpp" line="102"/>
         <source>It is a light and powerful application, written in Qt.</source>
-        <translation>Это легкое и мощное приложение, написанное на Qt.</translation>
+        <translation>Это лёгкое и мощное приложение, написанное на Qt.</translation>
     </message>
     <message>
         <location filename="../src/core/ui/about.cpp" line="105"/>
         <source>Website</source>
-        <translation>Сайт</translation>
+        <translation>Веб-сайт</translation>
     </message>
     <message>
         <location filename="../src/core/ui/about.cpp" line="109"/>
@@ -41,7 +41,7 @@
     <message>
         <location filename="../src/core/ui/about.cpp" line="113"/>
         <source>Copyright &amp;copy; 2009-2013, Artem &apos;DOOMer&apos; Galichkin</source>
-        <translation>Copyright &amp;copy; 2009-2013, Артём &apos;DOOMer&apos; Галичкин</translation>
+        <translation>Автор &amp;copy; 2009-2013, Артём &apos;DOOMer&apos; Галичкин</translation>
     </message>
     <message>
         <location filename="../src/core/ui/about.cpp" line="123"/>
@@ -131,12 +131,12 @@
     <message>
         <location filename="../src/core/ui/about.cpp" line="159"/>
         <source>Dual monitor support in Linux</source>
-        <translation>Поддержка работы на двух мониторах  в Linux</translation>
+        <translation>Поддержка двух мониторов в Linux</translation>
     </message>
     <message>
         <location filename="../src/core/ui/about.cpp" line="160"/>
         <source>win32-build [Windows XP and 7]</source>
-        <translation>win32-версии [Windows XP and 7]</translation>
+        <translation>win32-версии [Windows XP и 7]</translation>
     </message>
     <message>
         <location filename="../src/core/ui/about.cpp" line="161"/>
@@ -302,7 +302,7 @@
     <message>
         <location filename="../src/core/ui/mainwindow.ui" line="157"/>
         <source>None</source>
-        <translation type="unfinished">Нет</translation>
+        <translation>Ни одного</translation>
     </message>
     <message>
         <location filename="../src/core/ui/mainwindow.cpp" line="492"/>
@@ -404,7 +404,8 @@
 right click to fit to edges,
 double click or press Enter
 to take a screenshot.</source>
-        <translation type="unfinished"></translation>
+        <translation>Удерживая клавишу мыши и перемещая курсор, нарисуйте прямоугольник.
+Затем щёлкните два раза или нажмите Ввод, чтобы получить снимок экрана.</translation>
     </message>
     <message>
         <location filename="../src/core/regionselect.cpp" line="202"/>
@@ -615,12 +616,13 @@ to take a screenshot.</source>
         <location filename="../src/core/ui/configwidget.ui" line="407"/>
         <source>If this is unchecked, the selected area
 might become larger to fit to outer edges</source>
-        <translation type="unfinished"></translation>
+        <translation>Если не отмечено, по щелчку правой кнопкой выделенная область
+будет увеличена, чтобы включить внешние видимые границы</translation>
     </message>
     <message>
         <location filename="../src/core/ui/configwidget.ui" line="411"/>
         <source>Fit to edges inside selected area by right clicking</source>
-        <translation type="unfinished"></translation>
+        <translation>По щелчку правой кнопкой уменьшать выбранную область до видимых граней внутри оной</translation>
     </message>
     <message>
         <location filename="../src/core/ui/configwidget.ui" line="516"/>
